==> paraview-5.10.1-9-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsIOGeneralModule.h <==

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H
#define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSIOGENERAL_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#    ifdef VTKExtensionsIOGeneral_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H */

==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsIOGeneralModule.h <==

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H
#define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSIOGENERAL_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_EXPORT
#    ifdef VTKExtensionsIOGeneral_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSIOGENERAL_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_NO_EXPORT VTKPVVTKEXTENSIONSIOGENERAL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSIOGENERAL_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVVTKExtensionsIOGeneralModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVVTKEXTENSIONSIOGENERAL_EXPORT_H */
